`scrape_files` is a tool to help scrape things online to your local machine.
Currently, it supports scraping images in a web page as well as scraping and converting htmls to well-formatted markdowns for easy reading.

# Installation
```python
pip install scrape_files
```

